==> Gridcoin-Research-5.3.3.0.tar.gz: Gridcoin-Research-5.3.3.0/src/qt/locale/bitcoin_th_TH.ts <==
<TS language="th_TH" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>สร้างที่อยู่ใหม่</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;สร้างใหม่</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>คัดลอกที่อยู่ที่ถูกเลือกไปยัง คลิปบอร์ดของระบบ</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;คัดลอก</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>ลบที่อยู่ที่เลือกไว้ในขณะนี้จากรายการ</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;ลบ</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>ช่องสำหรับ รหัสผ่าน</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>ใส่รหัสผ่าน</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>รหัสผา่นใหม่</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>กรุณากรอกรหัสผ่านใหม่อีกครั้งหนึ่ง</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>เซ็นต์ชื่อด้วย &amp;ข้อความ...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;ภาพรวม</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>แสดงภาพรวมทั่วไปของกระเป๋าเงิน</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>เรียกดูประวัติการทำธุรกรรม</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;ออก</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>ออกจากโปรแกรม</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;ตัวเลือก...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;กระเป๋าเงินเข้ารหัส</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;เปลี่ยนรหัสผ่าน...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>เปลี่ยนรหัสผ่านที่ใช้สำหรับการเข้ารหัสกระเป๋าเงิน</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;หน้าต่าง Debug</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>เปิด แผลงควบคุม debugging และ diagnostic</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;ยืนยันข้อความ...</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>กระเป๋าเงิน</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;ส่ง</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;รับ</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;แสดง / ซ่อน</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;ไฟล์</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;การตั้งค่า</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;ช่วยเหลือ</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation><numerusform>%n บล็อกในประวัติรายการ ได้รับการดำเนินการเรียบร้อยแล้ว</numerusform></translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>ทันสมัย</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>กำลังตามให้ทัน...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>รายการที่ส่ง</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>การทำรายการขาเข้า</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>กระเป๋าเงินถูก &lt;b&gt;เข้ารหัส&lt;/b&gt; และในปัจจุบัน &lt;b&gt;ล็อค &lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>จำนวน:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>ไบต์:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>จำนวน:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>ค่าธรรมเนียม:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>ส่วนที่เหลือจากค่าธรรมเนียม:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>เงินทอน:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>จำนวน</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>วันที่</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>การยืนยัน</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>ยืนยันแล้ว</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>แก้ไขที่อยู่</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;ป้ายชื่อ</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;ที่เก็บ</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>ตัวเลือก</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;หลัก</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;เน็ตเวิร์ก</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>จองพอร์ต โดยใช้ &amp;UPnP</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;พอร์ต</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>พอร์ตของพร็อกซี่ (ตัวอย่าง 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;วันโดว์</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>แสดงเทรย์ไอคอน หลังมืนิไมส์วินโดว์ เท่านั้น</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>รูป</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>ส่งเหรียญ</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>จำนวน:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>ไบต์:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>จำนวน:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>ค่าธรรมเนียม:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>ส่วนที่เหลือจากค่าธรรมเนียม:</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;ชื่อ:</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished"><numerusform /></translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error</source>
        <translation>ข้อผิดพลาด</translation>
    </message>
</context>
</TS>

==> Gridcoin-Research-5.4.9.0.tar.gz: Gridcoin-Research-5.4.9.0/src/qt/locale/bitcoin_th_TH.ts <==
<TS language="th_TH" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>สร้างที่อยู่ใหม่</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;สร้างใหม่</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>คัดลอกที่อยู่ที่ถูกเลือกไปยัง คลิปบอร์ดของระบบ</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;คัดลอก</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>ลบที่อยู่ที่เลือกไว้ในขณะนี้จากรายการ</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;ลบ</translation>
    </message>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>ช่องสำหรับ รหัสผ่าน</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>ใส่รหัสผ่าน</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>รหัสผา่นใหม่</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>กรุณากรอกรหัสผ่านใหม่อีกครั้งหนึ่ง</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>กระเป๋าเงิน</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;ภาพรวม</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>แสดงภาพรวมทั่วไปของกระเป๋าเงิน</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;ส่ง</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;รับ</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>เรียกดูประวัติการทำธุรกรรม</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;ออก</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>ออกจากโปรแกรม</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;ตัวเลือก...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;แสดง / ซ่อน</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;กระเป๋าเงินเข้ารหัส</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;เปลี่ยนรหัสผ่าน...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>เปลี่ยนรหัสผ่านที่ใช้สำหรับการเข้ารหัสกระเป๋าเงิน</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>เซ็นต์ชื่อด้วย &amp;ข้อความ...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;ยืนยันข้อความ...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;หน้าต่าง Debug</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>เปิด แผลงควบคุม debugging และ diagnostic</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;ไฟล์</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;การตั้งค่า</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;ช่วยเหลือ</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>ทันสมัย</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>กำลังตามให้ทัน...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>รายการที่ส่ง</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>การทำรายการขาเข้า</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>กระเป๋าเงินถูก &lt;b&gt;เข้ารหัส&lt;/b&gt; และในปัจจุบัน &lt;b&gt;ล็อค &lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>จำนวน:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>ไบต์:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>จำนวน:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>ค่าธรรมเนียม:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>ส่วนที่เหลือจากค่าธรรมเนียม:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>เงินทอน:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>จำนวน</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>วันที่</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>การยืนยัน</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>ยืนยันแล้ว</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>แก้ไขที่อยู่</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;ป้ายชื่อ</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;ที่เก็บ</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>ตัวเลือก</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;หลัก</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;เน็ตเวิร์ก</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>จองพอร์ต โดยใช้ &amp;UPnP</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;พอร์ต</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>พอร์ตของพร็อกซี่ (ตัวอย่าง 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;วันโดว์</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>แสดงเทรย์ไอคอน หลังมืนิไมส์วินโดว์ เท่านั้น</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>รูป</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>ส่งเหรียญ</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>จำนวน:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>ไบต์:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>จำนวน:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>ค่าธรรมเนียม:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>ส่วนที่เหลือจากค่าธรรมเนียม:</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;ชื่อ:</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error</source>
        <translation>ข้อผิดพลาด</translation>
    </message>
</context>
</TS>
